@@ -32,7 +32,7 @@ function PropertyWatcher(propertyEditor, sender, propertyType) {
 
 /**
  * Called when a property has been changed by the user. Triggers
- * a transaction to change the propery of all selected entities
+ * a transaction to change the property of all selected entities
  * that match the current entity type filter.
  */
 PropertyWatcher.prototype.propertyChanged = function(value) {
@@ -105,7 +105,7 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
 
 /**
  * Called when a custom property has been deleted by the user. Triggers
- * a transaction to delete the propery from all selected entities
+ * a transaction to delete the property from all selected entities
  * that match the current entity type filter.
  */
 PropertyWatcher.prototype.propertyRemoved = function() {
@@ -167,7 +167,7 @@ IndexWatcher.prototype.indexChanged = function(index) {
     }
 
 
-    // preview postition in drawing:
+    // preview position in drawing:
     di.clearPreview();
     var r = view.mapDistanceFromView(10);
     di.addAuxShapeToPreview(new RCircle(new RVector(x, y), r));
@@ -186,6 +186,11 @@ IndexWatcher.prototype.indexChanged = function(index) {
 function PropertyEditorImpl(basePath) {
     RPropertyEditor.call(this);
 
+    if (isNull(basePath)) {
+        // only used to initialize prototype for derived class:
+        return;
+    }
+
     this.setEntityTypeFilter(RS.EntityAll);
     this.widget = WidgetFactory.createWidget(basePath, "PropertyEditor.ui");
     this.basePath = basePath;
@@ -362,20 +367,26 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
     if (!onlyChanges) {
         // create geometry group box with grid layout:
         this.geometryGroup = new QGroupBox(qsTr("Specific Properties"), this.widget);
+        this.geometryGroup.objectName = "GeometryGroup";
         layout.insertWidget(2, this.geometryGroup);
 
         // grid layout with three columns and N rows for N property controls:
         gridLayoutGeometry = new QGridLayout(this.geometryGroup);
         gridLayoutGeometry.setVerticalSpacing(2);
+        gridLayoutGeometry.setHorizontalSpacing(2);
+        // label:
         gridLayoutGeometry.setColumnStretch(0,0);
+        // control:
         gridLayoutGeometry.setColumnStretch(1,1);
-        gridLayoutGeometry.setColumnStretch(2,0);
+        // control or additional controls (e.g. clear button for dimension label):
+        gridLayoutGeometry.setColumnStretch(2,1);
         this.geometryGroup.setLayout(gridLayoutGeometry);
 
         // child properties
         // (block attributes shown when block reference is selected):
         // create child property group box with grid layout:
         this.childGroup = new QGroupBox(qsTr("Dependent Entities"), this.widget);
+        this.childGroup.objectName = "ChildGroup";
         layout.insertWidget(3, this.childGroup);
 
         // grid layout with four columns and N rows for N property controls:
@@ -666,7 +677,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                             group===RSettings.getAppId() && !attributes.isUndeletable()) {
 
                             var removeCustomPropertyButton = new QToolButton(this.widget);
-                            removeCustomPropertyButton.icon = new QIcon(this.basePath + "/RemoveCustomProperty.svg");
+                            removeCustomPropertyButton.icon = new QIcon(autoPath(this.basePath + "/RemoveCustomProperty.svg"));
                             removeCustomPropertyButton.iconSize = new QSize(12,12);
                             removeCustomPropertyButton.toolTip = qsTr("Remove this property from selected objects");
                             var name = propertyTypeId.getCustomPropertyName();
@@ -759,7 +770,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
     if (!isNull(gridLayoutCustom)) {
         if (RSettings.isXDataEnabled() && RSettings.getBoolValue("PropertyEditor/AddCustomProperties", true)!==false) {
             var addCustomPropertyButton = new QToolButton(this.widget);
-            addCustomPropertyButton.icon = new QIcon(this.basePath + "/AddCustomProperty.svg");
+            addCustomPropertyButton.icon = new QIcon(autoPath(this.basePath + "/AddCustomProperty.svg"));
             addCustomPropertyButton.iconSize = new QSize(12,12);
             addCustomPropertyButton.toolTip = qsTr("Add custom property to selected objects");
             addCustomPropertyButton.objectName = "AddCustomProperty";
@@ -774,7 +785,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
 /**
  * Initializes a control for the given property.
  *
- * \param propertyTypeId The propery the returned control edits.
+ * \param propertyTypeId The property the returned control edits.
  * \param onlyChanges Control already exists and only need to be re-initialized.
  * \param control The control to initialize if it is already known by the caller.
  *
@@ -845,6 +856,23 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
                     objectName, propertyTypeId, onlyChanges, control, false, true);
     }
 
+    // DIMLUNIT: combo box with DIMLUNIT choices:
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimlunit.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimtad.getId() ||
+             //propertyTypeId.getId()===RDimensionEntity.PropertyDimdsep.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimzin.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimdec.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimaunit.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimazin.getId() ||
+             propertyTypeId.getId()===RDimensionEntity.PropertyDimadec.getId()) {
+        controls = this.initChoiceControls(
+                    objectName, propertyTypeId, onlyChanges, control, false, true);
+    }
+
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimdsep.getId()) {
+        controls = this.initStringControls(objectName, propertyTypeId, onlyChanges, control);
+        //controls[0].maxLength = 1;
+    }
 
     // Hatch pattern: combo box with hatch names:
     else if (propertyTypeId.getId()===RHatchEntity.PropertyPatternName.getId()) {
@@ -986,7 +1014,10 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
             if (RSettings.getBoolValue("PropertyEditor/FormatAsDecimal", false)!==true &&
                 !attributes.isAngleType() &&
                 !attributes.isAreaType() &&
-                !attributes.isUnitLess() /*&&
+                !attributes.isUnitLess() &&
+                !attributes.isPercentage() &&
+                !attributes.isScaleType()
+                /*&&
                 (document.getLinearFormat()===RS.Fractional ||
                  document.getLinearFormat()===RS.FractionalStacked)*/) {
 
@@ -1027,6 +1058,8 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
                     'propertyChanged');
     }
 
+    control.cursorPosition = 0;
+
     return new Array(control);
 };
 
@@ -1067,7 +1100,7 @@ PropertyEditorImpl.prototype.initStringControls = function(objectName, propertyT
         clearButton = new QToolButton(this.geometryGroup);
         clearButton.objectName = objectName + "_clear";
         clearButton.iconSize = new QSize(12,12);
-        clearButton.icon = new QIcon(this.basePath + "/Clear.svg");
+        clearButton.icon = new QIcon(autoPath(this.basePath + "/Clear.svg"));
         clearButton.toolTip = qsTr("Use auto measurement");
         clearButton.clicked.connect(function() {
             control.text = "";
@@ -1081,6 +1114,8 @@ PropertyEditorImpl.prototype.initStringControls = function(objectName, propertyT
                     'propertyChanged');
     }
 
+    control.cursorPosition = 0;
+
     if (isNull(clearButton)) {
         return new Array(control);
     }
@@ -1196,6 +1231,27 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
     else if (propertyTypeId.getId()===RTextEntity.PropertyVAlign.getId()) {
         WidgetFactory.initVAlignCombo(control);
     }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimlunit.getId()) {
+        WidgetFactory.initDimlunitCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimtad.getId()) {
+        WidgetFactory.initDimtadCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimzin.getId()) {
+        WidgetFactory.initDimzinCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimdec.getId()) {
+        WidgetFactory.initDimdecCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimaunit.getId()) {
+        WidgetFactory.initDimaunitCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimazin.getId()) {
+        WidgetFactory.initDimazinCombo(control);
+    }
+    else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimadec.getId()) {
+        WidgetFactory.initDimadecCombo(control);
+    }
     else if (propertyTypeId.getId()===RPolylineEntity.PropertyOrientation.getId()) {
         WidgetFactory.initOrientationCombo(control);
     }
@@ -1355,7 +1411,7 @@ PropertyEditorImpl.prototype.requestAllProperties = function() {
 };
 
 PropertyEditorImpl.prototype.getAdjustedPropertyValue = function(propertyTypeId) {
-    // show handle as hex reprensentation (string):
+    // show handle as hex representation (string):
     if (propertyTypeId.getId()===RObject.PropertyHandle.getId()) {
         var value = this.getPropertyValue(propertyTypeId);
         if (value===RObject.INVALID_HANDLE) {
